/* friedman.h
 */
#ifndef FRIEDMAN_H
    #define FRIEDMAN_H

    #include <stdio.h>
    #include <stdlib.h>
    #include <string.h>
    #include <math.h>

    #define VERSION     "1.24 (Jan 17, 2002) http://ff123.net/"
    #define MAXCHAR     255
    #define MAXSAMPLES  8
    #define DELTA       1E-7   /* for doing floating-point comparisons */
    #define INFINITY    10000  /* for calculating Tukey's HSD */

    enum {FALSE, TRUE};
    enum {NO_ERROR, ERROR};
    enum {NO_INCR, INCR};
    enum {SCREEN, LOGFILE};
    enum {FRIEDMAN, ANOVA, TUKEYP, TUKEYNP};

    typedef struct {
        float data[MAXSAMPLES];  /* data to be sorted */
        int num[MAXSAMPLES];     /* numbering of data */
    } samples_t;

    /* function prototypes from friedman.c */
    void init(void);
    int rank(float rawdata[], float rankdata[], int tdata[]);
    int read_input(void);
    int process_options(int argnum, char *argv[]);
    void usage_error(void);
    int parse_command_line(int argc, char *argv[]);
    float calc_T(void);
    void calc_F(void);
    float calcSD(void);
    float fried_pval(float ranksumdiff);
    void construct_sd_matrix(FILE *output);
    void print_info(int device);
    int assess_signficance(FILE *output);
    void version(FILE *output);

    /* function prototypes from tukey.c */
    float get_tukey_q(float alpha,  int t, int dfE);

    /* function prototypes from utils.c */
    void sort(samples_t *sortedp, int N);

    /* function prototypes from chisq.c */
    double pochisq(double x, int df);
    double critchi(double p, int df);

    /* function prototypes from z.c */
    double poz(double z);
    double critz(double p);

    /* function prototypes from fisher.c */
    double fisher(int, int, double);
    double student(int, double);
    double critt(int, double);

#endif /* FRIEDMAN_H */
